@@ -10,14 +10,27 @@ published by the Free Software Foundation.
 
 import os
 import sys
+import logging
+import gettext
+
+_moduleLogger = logging.getLogger("quicknote")
+gettext.install('quicknote', unicode = 1)
 sys.path.append('/usr/lib/quicknote')
 
-import locale
-import gettext
-gettext.install('quicknote', unicode = 1)
 
-import libquicknote
+import constants
+import quicknote_gtk
+
 
 if __name__ == "__main__":
-	app = libquicknote.quicknoteclass()
+	try:
+		os.makedirs(constants._data_path_)
+	except OSError, e:
+		if e.errno != 17:
+			raise
+
+	logging.basicConfig(level=logging.DEBUG, filename=constants._user_logpath_)
+	_moduleLogger.info("quicknote %s-%s" % (constants.__version__, constants.__build__))
+
+	app = quicknote_gtk.QuicknoteProgram()
 	app.main()
